@@ -1,22 +1,25 @@
-import re
-
 from socket import gethostbyname
+from typing import Optional
 from urllib.parse import urlparse
 
+from .check import isdomain
+from .decorators import try_and_get_data
+
 
 # Network utils
 
-def get_domain_ip(domain: str):
+@try_and_get_data
+def get_domain_ip(domain: str) -> Optional[str]:
     return gethostbyname(domain)
 
 
 def get_host(url: str):
     """Get the host of the input url."""
 
-    if not re.match(r'https?:\/\/', url):
-        return url
+    if host := urlparse(url).hostname:
+        return host
 
-    return urlparse(url).hostname
+    return (isdomain(url) and url) or None
 
 
 def domains_is_ip(domains: list[str], ip: str):
