@@ -2,8 +2,6 @@ import random
 import re
 import string
 
-from typing import Union
-
 from .check import isbytes, isstr
 
 
@@ -25,7 +23,7 @@ def random_str(min_l: int = 8, max_l: int = 8):
     return ''.join(random.choice(_RANDOM_LETTERS) for i in range(random.randint(min_l, max_l)))
 
 
-def s2b(data: Union[bytes, str], encoding: str = 'utf-8'):
+def s2b(data: bytes | str, encoding: str = 'utf-8'):
     """Convert string to bytes."""
 
     if isstr(data):
@@ -35,7 +33,7 @@ def s2b(data: Union[bytes, str], encoding: str = 'utf-8'):
     return data
 
 
-def b2s(data: Union[bytes, str], encoding: str = 'utf-8'):
+def b2s(data: bytes | str, encoding: str = 'utf-8'):
     """Convert bytes to string."""
 
     if isbytes(data):
